api.alarms.v1.test_helpers.category package — Argus-Toolbelt 1.0 documentation

# api.alarms.v1.test_helpers.category package

## Submodules

## api.alarms.v1.test_helpers.category.get_categories module

`api.alarms.v1.test_helpers.category.get_categories.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category, respond with HTTP 403

`api.alarms.v1.test_helpers.category.get_categories.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category, respond with HTTP 404

`api.alarms.v1.test_helpers.category.get_categories.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category, respond with HTTP 200

`api.alarms.v1.test_helpers.category.get_categories.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category, respond with HTTP 401

## api.alarms.v1.test_helpers.category.get_category_by_id module

`api.alarms.v1.test_helpers.category.get_category_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/w+, respond with HTTP 403

`api.alarms.v1.test_helpers.category.get_category_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/w+, respond with HTTP 404

`api.alarms.v1.test_helpers.category.get_category_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/w+, respond with HTTP 200

`api.alarms.v1.test_helpers.category.get_category_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/w+, respond with HTTP 401

## api.alarms.v1.test_helpers.category.search_categories module

`api.alarms.v1.test_helpers.category.search_categories.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/search, respond with HTTP 403

`api.alarms.v1.test_helpers.category.search_categories.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/search, respond with HTTP 404

`api.alarms.v1.test_helpers.category.search_categories.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/search, respond with HTTP 200

`api.alarms.v1.test_helpers.category.search_categories.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/category/search, respond with HTTP 401

## Module contents